@@ -43,7 +43,7 @@ modelWeights= os.path.join(__location__, 'model_ft.pth')
 def transform_():
     transform = A.Compose(
     [A.Resize(128, 171, always_apply=True),A.CenterCrop(112, 112, always_apply=True),
-     A.Normalize(mean = [0.4552, 0.4550, 0.4530],std = [0.1918, 0.1870, 0.1905], always_apply=True)]
+     A.Normalize(mean = [0.43216, 0.394666, 0.37645],std = [0.22803, 0.22145, 0.216989], always_apply=True)]
      )
     return transform
 
@@ -503,7 +503,7 @@ def streaming_framesInference(frames):
     return class_c
 
 def streaming_predict(frames):
-    prediction,probb = streaming_framesInference(frames)
+    prediction= streaming_framesInference(frames)
     global predicted_class_name
     predicted_class_name = prediction
 
@@ -521,7 +521,7 @@ def start_streaming(streamingUrl):
             x = threading.Thread(target=streaming_predict, args=(l))
             x.start()
             l = []
-        if predicted_class_name == "fight":
+        if predicted_class_name == "accident":
             cv2.putText(frame, predicted_class_name, (10, 30), cv2.FONT_HERSHEY_SIMPLEX, 1, (0, 0, 255), 3)
         else:
             cv2.putText(frame, predicted_class_name, (10, 30), cv2.FONT_HERSHEY_SIMPLEX, 1, (0, 255, 0), 2)
